MGKit: Metagenomics Framework
=============================

.. image:: https://github.com/frubino/mgkit/workflows/Python%20package/badge.svg
    :alt: Building

The aim of this library [#]_ is to provide a series of useful modules and packages to make it easier to build custom pipelines for metagenomics or any kind of bioinformatics analysis. It integrates other well known python libraries in bioinformatics, like `HTSeq <http://www-huber.embl.de/users/anders/HTSeq/>`_, `pysam <https://code.google.com/p/pysam/>`_, `numpy <http://www.numpy.org>`_ and `scipy <http://www.scipy.org>`_.

Documentation is available at `<https://frubino.github.io>`_ Data and scripts used in the documentations are available at [#]_.

A discussion mailing list is available at `mgkit-users <https://groups.google.com/forum/#!forum/mgkit-users>`_.

Papers using MGKit
------------------

Rubino, F., Carberry, C., M Waters, S., Kenny, D., McCabe, M. S., & Creevey, C. J. (2017). Divergent functional isoforms drive niche specialisation for nutrient acquisition and use in rumen microbiome. The ISME Journal, 1–13. https://doi.org/10.1038/ismej.2016.172

Lambert, B. S., Raina, J. B., Fernandez, V. I., Rinke, C., Siboni, N., Rubino, F., … Stocker, R. (2017). A microfluidics-based in situ chemotaxis assay to study the behaviour of aquatic microbial communities. Nature Microbiology, 2(10), 1344–1349. https://doi.org/10.1038/s41564-017-0010-9

Hitch, T. C. A., Thomas, B. J., Friedersdorff, J. C. A., Ougham, H., & Creevey, C. J. (2018). Deep sequence analysis reveals the ovine rumen as a reservoir of antibiotic resistance genes. Environmental Pollution, 235, 571–575. https://doi.org/10.1016/j.envpol.2017.12.067

Computational haplotype recovery and long-read validation identifies novel isoforms of industrially relevant enzymes from natural microbial communities
Samuel M Nicholls, Wayne Aubrey, Arwyn Edwards, Kurt de Grave, Sharon Huws, Leander Schietgat, André Soares, Christopher J Creevey, Amanda Clare
bioRxiv 223404; doi: https://doi.org/10.1101/223404

Citing
------

Rubino, F. and Creevey, C.J. 2014. MGkit: Metagenomic Framework For The Study Of Microbial Communities. . Available at: `figshare <http://figshare.com/articles/MGkit_Metagenomic_Framework_For_The_Study_Of_Microbial_Communities/1269288>`_ [doi:10.6084/m9.figshare.1269288].`

a citation is also available using the *mgkit.cite()* function or using the `--cite` option on all scripts included. This will ouput the following

Links
-----

.. [#] `<https://github.com/frubino/mgkit>`_
.. [#] `<http://dx.doi.org/10.6084/m9.figshare.1588384>`_
